searchData={"items":[{"type":"module","title":"TreeSitter","doc":"Bindings for TreeSitter\n\n> #### It is NIF library {: .warning}\n>\n> This library uses NIF to provide tree-sitter bindings,\n> so if there will be segmentation faults or any errors\n> on the NIF side - **it will crash whole Erlang VM**\n>\n> So wrap this library in a separate OS process using\n> `Ports` or something else to prevent VM crashes.\n\nUsage example:\n\n```\n# Create parser\nparser = TreeSitter.new()\n\n# Create a language (check new_language/2 docs for more info)\nlanguage = TreeSitter.new_language(\"./languages/libtree-sitter-css.dylib\", \"tree_sitter_css\")\n\n# Set language to parser\n:ok = TreeSitter.set_language(parser, language)\n\n# Parse!\n{:ok, tree} = TreeSitter.parse_string(parser, \"body {color: red}\")\n\n# Covert to map or do queries\n{:ok, tree_map} = TreeSitter.to_map(tree)\n```","ref":"TreeSitter.html"},{"type":"type","title":"TreeSitter.capture/0","doc":"","ref":"TreeSitter.html#t:capture/0"},{"type":"type","title":"TreeSitter.capture_result/0","doc":"","ref":"TreeSitter.html#t:capture_result/0"},{"type":"type","title":"TreeSitter.captures/0","doc":"","ref":"TreeSitter.html#t:captures/0"},{"type":"function","title":"TreeSitter.exec_query/2","doc":"Execute query for given tree","ref":"TreeSitter.html#exec_query/2"},{"type":"type","title":"TreeSitter.language/0","doc":"","ref":"TreeSitter.html#t:language/0"},{"type":"function","title":"TreeSitter.load_nif/0","doc":"","ref":"TreeSitter.html#load_nif/0"},{"type":"function","title":"TreeSitter.new/0","doc":"Initialize new parser\n\nYou must set language (see `new_language/2` and `set_language/2`) to use it for parsing","ref":"TreeSitter.html#new/0"},{"type":"function","title":"TreeSitter.new_langauge/2","doc":"Create language from compiled library (.so or .dylib).\n\nYou can get it by running 'make' in root of some parser for tree sitter.\n\n# Params\n`library` - path to the compiled library file\n\n`function` - function name, based on library name. For example tree-sitter-css lib must have 'tree_sitter_css' function name","ref":"TreeSitter.html#new_langauge/2"},{"type":"function","title":"TreeSitter.new_language/2","doc":"","ref":"TreeSitter.html#new_language/2"},{"type":"function","title":"TreeSitter.new_query/2","doc":"Create new query for given language","ref":"TreeSitter.html#new_query/2"},{"type":"function","title":"TreeSitter.parse_string/2","doc":"Parse string with given parser\n\nRemember that you should do `set_language/2` before","ref":"TreeSitter.html#parse_string/2"},{"type":"type","title":"TreeSitter.parser/0","doc":"","ref":"TreeSitter.html#t:parser/0"},{"type":"type","title":"TreeSitter.query/0","doc":"","ref":"TreeSitter.html#t:query/0"},{"type":"function","title":"TreeSitter.set_language/2","doc":"Set lagnuage for given parser\n\n# Params\n\n`parser` - parser reference\n\n`language` - language reference, that you created with `new_language/2`","ref":"TreeSitter.html#set_language/2"},{"type":"type","title":"TreeSitter.string_like/0","doc":"","ref":"TreeSitter.html#t:string_like/0"},{"type":"function","title":"TreeSitter.to_map/1","doc":"Convert native tree sitter tree to elixir map","ref":"TreeSitter.html#to_map/1"},{"type":"type","title":"TreeSitter.tree/0","doc":"","ref":"TreeSitter.html#t:tree/0"},{"type":"extras","title":"Tree-sitter Elixir","doc":"# Tree-sitter Elixir\n\nThis package provides Elixir bindings for the [Tree-sitter](https://tree-sitter.github.io/tree-sitter/) parsing library.","ref":"readme.html"},{"type":"extras","title":"Installation - Tree-sitter Elixir","doc":"1. Install the Tree-sitter C library:\n\n```bash\n# On macOS\nbrew install tree-sitter\n\n# On Ubuntu/Debian\napt-get install libtree-sitter-dev\n\n# On Fedora\ndnf install tree-sitter-devel\n```\n\n2. Add the package to your dependencies:\n\n```elixir\ndef deps do\n  [\n    {:tree_sitter, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Tree-sitter Elixir","doc":"```elixir\n# Create a parser\nparser = TreeSitter.new()\n\n# Load a language (provides the path to the shared library and function name)\nlanguage = TreeSitter.new_language(\"/path/to/tree-sitter-elixir.so\", \"tree_sitter\")\n\n# Set the language on the parser\n:ok = TreeSitter.set_language(parser, language)\n\n# Parse a string\ntree = TreeSitter.parse_string(parser, \"defmodule Test do\\n  def hello, do: :world\\nend\")\n\n# Create a query\n{:ok, query} = TreeSitter.new_query(language, \"\"\"\n(\n  (call_expression\n    function: (identifier) @function_name\n  )\n)\n\"\"\")\n\n# Execute the query against the tree\n{:ok, matches} = TreeSitter.exec_query(query, tree)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Helper Functions - Tree-sitter Elixir","doc":"You can also use the helper functions for a simpler workflow:\n\n```elixir\n# Parse a string with a given language in one step\ntree = TreeSitter.parse(\"/path/to/lang.so\", \"tree_sitter_lang\", \"source code...\")\n\n# Run a query in one step\n{:ok, matches} = TreeSitter.query(language, tree, \"\"\"\n(identifier) @id\n\"\"\")\n```","ref":"readme.html#helper-functions"},{"type":"extras","title":"Building Languages - Tree-sitter Elixir","doc":"To use this library, you'll need shared libraries (.so, .dylib, or .dll files) for each Tree-sitter language you want to use. You can build these from the language repositories:\n\n```bash\ngit clone https://github.com/tree-sitter/tree-sitter-elixir\ncd tree-sitter-elixir\nmake\n# The shared library will be in the build/ directory\n```","ref":"readme.html#building-languages"},{"type":"extras","title":"License - Tree-sitter Elixir","doc":"MIT","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}